@@ -8,7 +8,8 @@ for i in STlist:
         accis.addAccis(ScriptType='ex_ac',
                        Outputs='standard',
                        EnergyPlus_version='ep95',
-                       AdapStand=[1],
+                       TempCtrl='temp',
+                       ComfStand=[1],
                        CAT=[3],
                        ComfMod=[3],
                        NameSuffix=i+'_'+j,
