@@ -2,7 +2,8 @@ from accim.sim import accis
 accis.addAccis(ScriptType='ex_mm',
                Outputs='standard',
                EnergyPlus_version='ep95',
-               AdapStand=[1],
+               TempCtrl='temp',
+               ComfStand=[1],
                CAT=[1, 2, 3],
                ComfMod=[3],
                HVACmode=[2],
