@@ -13,7 +13,8 @@ for i in scriptTypeList:
                 ScriptType=i,
                 Outputs=j,
                 EnergyPlus_version=k,
-                AdapStand=[1],
+                TempCtrl='temp',
+                ComfStand=[1],
                 CAT=[1],
                 ComfMod=[1],
                 HVACmode=[2],
