@@ -10,7 +10,8 @@ class accimJob():
         genIDF
     from accim.sim.accim_Base import \
         setComfFieldsPeople, \
-        saveaccim
+        saveaccim, \
+        setPMVsetpoint
     from accim.sim.accim_Base_EMS import \
         addEMSActuatorsBase, \
         addEMSOutputVariableBase, \
@@ -42,28 +43,32 @@ class accimJob():
                  filename_temp,
                  ScriptType: str = None,
                  EnergyPlus_version: str = None,
+                 TempCtrl: str = None,
                  verboseMode: bool = True,
                  accimNotWorking: bool = False):
         from eppy import modeleditor
         from eppy.modeleditor import IDF
         self.accimNotWorking = accimNotWorking
 
-        if EnergyPlus_version.lower() == 'ep91':
+        if EnergyPlus_version.lower() == '9.1':
             iddfile = 'C:/EnergyPlusV9-1-0/Energy+.idd'
-        elif EnergyPlus_version.lower() == 'ep92':
+        elif EnergyPlus_version.lower() == '9.2':
             iddfile = 'C:/EnergyPlusV9-2-0/Energy+.idd'
-        elif EnergyPlus_version.lower() == 'ep93':
+        elif EnergyPlus_version.lower() == '9.3':
             iddfile = 'C:/EnergyPlusV9-3-0/Energy+.idd'
-        elif EnergyPlus_version.lower() == 'ep94':
+        elif EnergyPlus_version.lower() == '9.4':
             iddfile = 'C:/EnergyPlusV9-4-0/Energy+.idd'
-        elif EnergyPlus_version.lower() == 'ep95':
+        elif EnergyPlus_version.lower() == '9.5':
             iddfile = 'C:/EnergyPlusV9-5-0/Energy+.idd'
-        elif EnergyPlus_version.lower() == 'ep96':
+        elif EnergyPlus_version.lower() == '9.6':
             iddfile = 'C:/EnergyPlusV9-6-0/Energy+.idd'
+        elif EnergyPlus_version.lower() == '22.1':
+            iddfile = 'C:\EnergyPlusV22-1-0\Energy+.idd'
+        elif EnergyPlus_version.lower() == '22.2':
+            iddfile = 'C:\EnergyPlusV22-2-0\Energy+.idd'
         else:
             raise ValueError("""EnergyPlus version not supported.\n
-                                     Only works for versions between EnergyPlus 9.1 (enter ep91) and
-                                     EnergyPlus 9.6(enter ep96).""")
+                                     Only works for versions between EnergyPlus 9.1 (enter 9.1) and EnergyPlus 22.2 (enter 22.2)""")
         if verboseMode:
             print('IDD location is: '+iddfile)
         IDF.setiddname(iddfile)
@@ -78,19 +83,47 @@ class accimJob():
         self.filename = filename_temp+'_pymod'
 
         # print(self.filename)
-
         self.occupiedZones_orig = []
+
+        occupiedZones_orig_osm = []
+        if len([h for h in self.idf1.idfobjects['zonelist']]) > 0:
+            if len(self.idf1.idfobjects['zone']) == 1:
+                no_of_zones = range(1, 2)
+            else:
+                no_of_zones = range(1, len(self.idf1.idfobjects['zone']))
+
+            for i in no_of_zones:
+                for j in self.idf1.idfobjects['zonelist']:
+                    for k in self.idf1.idfobjects['zone']:
+                        if k.Name in j[f'Zone_{i}_Name']:
+                            occupiedZones_orig_osm.append(k.Name)
+
+            # for i in self.idf1.idfobjects['zone']:
+            #     if all(i.Name not in [j for j in occupiedZones_orig_osm]):
+            #         occupiedZones_orig_osm.append(i.Name)
+
+        occupiedZones_orig_dsb = []
         for i in self.idf1.idfobjects['ZONE']:
             for k in self.idf1.idfobjects['PEOPLE']:
                 if i.Name in k.Name:
-                    self.occupiedZones_orig.append(i.Name.upper())
-        self.occupiedZones = [i.replace(':', '_') for i in self.occupiedZones_orig]
+                    occupiedZones_orig_dsb.append(i.Name.upper())
+
+        if any([':' in i for i in occupiedZones_orig_dsb]):
+            self.occupiedZones_orig = occupiedZones_orig_dsb
+            self.occupiedZones = [i.replace(':', '_') for i in self.occupiedZones_orig]
+            self.origin_dsb = True
+        else:
+            self.occupiedZones_orig = occupiedZones_orig_osm
+            self.occupiedZones = [i.replace(' ', '_') for i in self.occupiedZones_orig]
+            self.origin_dsb = False
+
+
         if verboseMode:
             print(f'The occupied zones in the model {filename_temp} are:')
             print(*self.occupiedZones_orig, sep="\n")
 
-        if (ScriptType.lower() == 'vrfsystem' or
-            ScriptType.lower() == 'vrf' or
+        if (ScriptType.lower() == 'vrfsystem_mm' or
+            ScriptType.lower() == 'vrf_mm' or
             ScriptType.lower() == 'existinghvac_mm' or
             ScriptType.lower() == 'ex_mm'
         ):
@@ -102,7 +135,7 @@ class accimJob():
                       ['AirflowNetwork:MultiZone:Component:DetailedOpening']
                       if window.Name.endswith('_Win')]:
                 for k in self.occupiedZones_orig:
-                    if i.split('_')[0] in k:
+                    if i.split('_')[0].lower() in k.lower():
                         self.windownamelist_orig.append(i)
 
             self.windownamelist = [i.replace(':', '_') for i in self.windownamelist_orig]
@@ -114,7 +147,7 @@ class accimJob():
                 print(f'The windows in the model {filename_temp} are:')
                 print(*self.windownamelist, sep="\n")
 
-        if ScriptType.lower() == 'vrfsystem' or ScriptType.lower() == 'vrf':
+        if 'vrf' in ScriptType.lower():
             self.zonenames = self.occupiedZones
             self.zonenames_orig = self.occupiedZones_orig
             if verboseMode:
@@ -141,7 +174,10 @@ class accimJob():
                     for j in range(len(self.ZCTlist)):
                         if self.ZCTlist[j].Control_1_Object_Type in TSPtypes[i]:
                             temp1.append(self.ZCTlist[j].Zone_or_ZoneList_Name.upper())
-                            temp2.append(self.ZCTlist[j].Zone_or_ZoneList_Name.upper().replace(":", "_"))
+                            if ':' in self.ZCTlist[j].Zone_or_ZoneList_Name:
+                                temp2.append(self.ZCTlist[j].Zone_or_ZoneList_Name.upper().replace(":", "_"))
+                            else:
+                                temp2.append(self.ZCTlist[j].Zone_or_ZoneList_Name.upper().replace(" ", "_"))
                             temp3.append(self.ZCTlist[j].Control_1_Name)
                 self.HVACzonelist.append([TSPtypes[i], temp1, temp2, temp3])
             del temp1, temp2, temp3
@@ -167,8 +203,10 @@ class accimJob():
                         continue
                     else:
                         self.zonenames_orig.append(self.HVACzonelist[i][1][k])
-
-            self.zonenames = [i.replace(':', '_') for i in self.zonenames_orig]
+            if self.origin_dsb:
+                self.zonenames = [i.replace(':', '_') for i in self.zonenames_orig]
+            else:
+                self.zonenames = [i.replace(' ', '_') for i in self.zonenames_orig]
 
             if ScriptType.lower() == 'existinghvac_mm' or ScriptType.lower() == 'ex_mm':
 
